using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Controller
{
	/// <summary>
	/// This static class contains controller methods for the operations 
	/// defined for the Cable operation group.
	/// </summary>
	public static class CableOperations
	{
		/// <summary>
		/// Executes the Unplug operation in the 
		/// Cable group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Unplug operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteUnplug(Execution execution)
		{
			// get cable to unplug.  Should never be null, but just in case...
			Cable cable = execution.Target as Cable;
			if (cable == null)
				return ExecutionResult.NoActionResult;

			// first ask user for confirmation
			UserInterface ui = execution.UI;
			if (!ui.UserConfirms("Do you really want to unplug {0} from all connectors?", cable))
				return ExecutionResult.NoActionResult;

			// simply remove all connectors from cable's connector collection
			cable.PluggedInto.RemoveAll();    // don't use Clear - it doesn't affect persistent storage

			return ExecutionResult.CommitResult;    // commits changes to persistent storage
		}

	}
}

