using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Controller
{
	/// <summary>
	/// This static class contains controller methods for the operations 
	/// defined for the Device operation group.
	/// </summary>
	public static class DeviceOperations
	{
		/// <summary>
		/// Executes the Disconnect operation in the 
		/// Device group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Disconnect operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteDisconnect(Execution execution)
		{
			// get device to disconnect.  Should never be null, but just in case...
			Device device = execution.Target as Device;
			if (device == null)
				return ExecutionResult.NoActionResult;

			// first ask user for confirmation
			UserInterface ui = execution.UI;
			if (!ui.UserConfirms("Do you really want to disconnect all cables from {0}", device))
				return ExecutionResult.NoActionResult;

			// set cable in all connectors to null
			foreach (Connector connector in device.Connectors)
				connector.SetCable(null);

			return ExecutionResult.CommitResult;    // commits changes to persistent storage

		}

	}
}

