using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Controller
{
	/// <summary>
	/// This static class contains controller methods for the operations 
	/// defined for the View operation group.
	/// </summary>
	public static class ViewOperations
	{
		/// <summary>
		/// Executes the Parent operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Parent operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteParent(Execution execution)
		{
			return StandardOperations.ExecuteParent(execution);
		}

		/// <summary>
		/// Executes the Save workspace operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Save workspace operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteSaveWorkspace(Execution execution)
		{
			return StandardOperations.ExecuteSaveWorkspace(execution);
		}

		/// <summary>
		/// Executes the Restore workspace operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Restore workspace operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteRestoreWorkspace(Execution execution)
		{
			return StandardOperations.ExecuteRestoreWorkspace(execution);
		}

		/// <summary>
		/// Executes the Maintain workspaces operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Maintain workspaces operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteMaintainWorkspaces(Execution execution)
		{
			return StandardOperations.ExecuteMaintainWorkspaces(execution);
		}

	}
}

