using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  AddPane operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class AddPaneOperations
	{
		/// <summary>
		/// Determines whether the To left operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ToLeftPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ToLeftPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the To left operation in the 
		/// AddPane group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the To left operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteToLeft(Execution execution)
		{
			return StandardOperations.ExecuteToLeft(execution);
		}

		/// <summary>
		/// Determines whether the To right operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ToRightPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ToRightPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the To right operation in the 
		/// AddPane group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the To right operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteToRight(Execution execution)
		{
			return StandardOperations.ExecuteToRight(execution);
		}

		/// <summary>
		/// Determines whether the Above operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence AbovePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.AbovePresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Above operation in the 
		/// AddPane group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Above operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteAbove(Execution execution)
		{
			return StandardOperations.ExecuteAbove(execution);
		}

		/// <summary>
		/// Determines whether the Below operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence BelowPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.BelowPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Below operation in the 
		/// AddPane group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Below operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteBelow(Execution execution)
		{
			return StandardOperations.ExecuteBelow(execution);
		}

	}
}
