using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  Cable operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class CableOperations
	{
		/// <summary>
		/// Determines whether the Unplug operation should be enabled and/or
		/// visible for a particular potential target Cable.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Cable on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>An OperationPresence containing the operation visibility and
		/// a tooltip.</returns>
		public static OperationPresence UnplugPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return target != null 
				? OperationPresence.Enabled("Execute the Unplug operation") 
				: OperationPresence.Disabled("No object is selected");
		}

	}
}
