using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  Collection operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class CollectionOperations
	{
		/// <summary>
		/// Determines whether the Refresh all operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence RefreshAllPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.RefreshAllPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the New operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence NewPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.NewPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Delete operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence DeletePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.DeletePresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Add operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence AddPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.AddPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Remove operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence RemovePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.RemovePresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Insert operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence InsertPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.InsertPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Move up operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence MoveUpPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.MoveUpPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Move down operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence MoveDownPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.MoveDownPresence(session, target, collection);
		}


	}
}
