using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  File operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class FileOperations
	{
		/// <summary>
		/// Determines whether the Exit operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ExitPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ExitPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Save operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence SavePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.SavePresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Revert operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence RevertPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.RevertPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Login operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence LoginPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.LoginPresence(session, target, collection);
		}


	}
}
