using System;
using System.Collections.Generic;
using System.Reflection;
using System.Text;
using Persistate;
using Persistate.UI.Desktop;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This class contains the InitUserInterface method which is called 
	/// from the Main method of the StartUp class, and also by the Persistate
	/// Viewer application when starting a session for the DeviceNetwork package.
	/// </summary>
	public static class InitialiseUserInterface
	{
		/// <summary>
		/// Logs in and shows start-up content in the user interface.
		/// </summary>
		/// <param name="ui">The user interface in which to show content.</param>
		/// <param name="title">The title to use for created window(s).</param>
		public static void InitUserInterface(DesktopUserInterface ui, string title)
		{
			// TODO Develop this to show the data you want at start up.

			// Add any images from this assembly's resources
			PWindow.AddResourceImages(Properties.Resources.ResourceManager);

			// By default, login with user currently logged in to OS
			ExecutionResult result = Operation.Login.Execute(null, null, 
				Credentials.CurrentUserCredentials());
			
			// if login fails, throw exception to terminate session
			if (result.ResultAction != ResultAction.Commit) 
				throw new Exception(result.SimpleMessage);

			// Create a single window using the default workspace and given title
			PWindow window = (PWindow)ui.CreateWindow(null, title);

			// Show the menu & toolbar in the top controls pane 
			window.Show(The.Network, The.Network.Class.Layouts[Layout.NameKey, 
				"NetworkControls"], "controls");

			// Show the Network tree in the left hand navigation pane.
			window.Show(The.Network, The.Network.Class.Layouts[Layout.NameKey, 
				"NetworkTree"], "navigation");

			// Show the status bar in the bottom status bar pane
			window.Show(null, Layout.StatusStrip, "status bar");

			// Make the window visible
			ui.ShowWindow(window);
		}
	}
}
