using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  Object operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class ObjectOperations
	{
		/// <summary>
		/// Determines whether the Refresh operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence RefreshPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.RefreshPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Show operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ShowPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ShowPresence(session, target, collection);
		}


	}
}
