using System;
using System.Collections.Generic;
using System.Text;
using Persistate;

namespace DeviceNetwork.Model
{
	/// <summary>  
	/// TODO write summary documentation
	/// </summary>
	public partial class Connector : Persistent
	{

		private static List<Device> devicesToUpdate = new List<Device>();

		/// <summary>
		/// Set up event handling
		/// </summary>
		public static void SetEventHandlers(Session session)
		{
			Connector.ItsObjectClass.InstanceAssociated
				+= new LinkageEventHandler(Connector_InstanceAssociated);
			Connector.ItsObjectClass.InstanceDissociated
				+= new LinkageEventHandler(Connector_InstanceDissociated);

			session.Committed += new CommittedEventHandler(session_Committed);
		}

		// when connector added to cable's plugged in collection, associate cable to connector
		private static void Connector_InstanceAssociated(object sender, LinkageEventArgs args)
		{
			Cable cable = args.Container as Cable;
			if (cable != null)
				((Connector)args.Containee).SetCable(cable);
		}

		// when connector removed from cable's plugged in collection, dissociate cable from connector
		private static void Connector_InstanceDissociated(object sender, LinkageEventArgs args)
		{
			Cable cable = args.Container as Cable;
			if (cable != null)
				((Connector)args.Containee).SetCable(null);
		}

		// after commits, check if any ConnectedDevice collections need updated
		private static void session_Committed(object sender, CommittedEventArgs e)
		{
			lock (devicesToUpdate) {
				if (devicesToUpdate.Count > 0) {
					foreach (Device device in devicesToUpdate)
						device.SelectConnectedDevices(device);
					devicesToUpdate.Clear();
				}
			}
		}

		/// <summary>
		/// Sets a new Cable into this connector. 
		/// </summary>
		/// <param name="newCable">The cable to set.  Supply null to unplug existing cable.</param>
		public void SetCable(Cable newCable)
		{
			lock (devicesToUpdate) {
				UpdateDevice(ParentDevice);
				UpdateConnectedDevices(Cable);
				UpdateConnectedDevices(newCable);

				Cable = newCable;
			}
		}

		private static void UpdateConnectedDevices(Cable cable)
		{
			if (cable != null)
				foreach (Connector connector in cable.PluggedInto)
					UpdateDevice(connector.ParentDevice);
		}

		private static void UpdateDevice(Device device)
		{
			if (!devicesToUpdate.Contains(device))
				devicesToUpdate.Add(device);
		}
	}

}