using System;
using System.Reflection;
using Persistate;
using Persistate.UI.Desktop;
using DeviceNetwork.Model;
using DeviceNetwork.Desktop;
using DeviceNetwork.Controller;

namespace DeviceNetwork.StartUp
{
	/// <summary>
	/// This is the start-up class for the Device Network application.  This is the entry
	/// point used when the application is run in stand-alone mode.
	/// </summary>
	public class StartUp
	{
		/// <summary>
		/// Entry point for the Device Network application.
		/// </summary>
		/// <param name="args">The first supplied argument will be used as the name
		/// of the connection settings set retrieved from the registry.  If null, 
		/// the default settings are used. </param>
		[STAThread]
		static void Main(string[] args)
		{
			// Create a new session with a desktop user interface
			Assembly model = typeof(DeviceNetwork.Model.The).Assembly;
			DesktopUserInterface ui = new DesktopUserInterface();
			try {
				string settingsName = args.Length > 0 ? args[0] : null;
				Session session = DbaSession.StartNewSession(ui, model, settingsName);
				if (session == null)
					return;	// user cancelled from connect dialogue
				InitialiseController.InitController(session);
				InitialiseUserInterface.InitUserInterface(ui, "Device Network");
			} catch (Exception ex) {
				ui.ReportError(Utl.ExceptionText(ex), Utl.ExceptionText(ex, true));
				ui.Exit(null);
				return;
			}
		}
	}
}
